#
# spec file for package FlightGear-data
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define main_version 2017.3
Name:           FlightGear-data
Version:        %{main_version}.1
Release:        bp151.3.1
Summary:        FlightGear base scenery and data files
License:        GPL-2.0
Group:          Amusements/Games/3D/Simulation
Url:            http://www.flightgear.org/
Source0:        https://sourceforge.net/projects/flightgear/files/release-%{main_version}/FlightGear-%{version}-data.tar.bz2
# Remove warnings about hidden files to make other rpmlint warnings readable.
Source1:        FlightGear-data-rpmlintrc
NoSource:       0
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-xml
BuildRequires:  texlive-latex-bin-bin
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Recommends:     FlightGear-docs-%{version}

%description
This package contains the base scenery and aircraft for FlightGear.
It must be installed together with the FlightGear flight simulator package.

%package -n FlightGear-docs
Summary:        FlightGear Documentation
Group:          Documentation
Requires:       %{name} = %{version}

%description -n FlightGear-docs
This package contains pdf, text and html documentation for the
FlightGear flight simulator package.

%prep

%build

%install
install -d %{buildroot}%{_datadir}/flightgear
cd %{buildroot}%{_datadir}/flightgear
tar -jxf %{SOURCE0} --strip-components 1

# cleanup temporary files and fix permissions
find %{buildroot}%{_datadir}/flightgear -name '.git*' -print -delete -name '*#*' -print -delete -name "*.bak" -print -delete
dos2unix -c ascii Docs/model-combined.eff/README.model-combined.eff
# fix files not in utf-8
for path in Thanks Docs/README.xmlparticles ; do
  iconv -f iso-8859-1 -t utf-8 -o "$path.utf8" "$path"
  mv -f "$path.utf8" "$path"
done

# Create html documentation and remove executable
cd Docs
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
./compile_docs.py
%endif
rm -f compile_docs.py
cd ../
# Move docs to default docdir
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
find %{buildroot}%{_datadir}/flightgear/Docs/ -name \*.log -print0 | xargs -0 rm # drop unneccesary TeX logs
mv %{buildroot}%{_datadir}/flightgear/Docs %{buildroot}%{_defaultdocdir}/%{name}/

find %{buildroot}%{_datadir}/flightgear -type f -exec chmod 0644 "{}" "+"
#Change permissions back for executable scripts
chmod -f 0755 `find %{buildroot}%{_datadir}/flightgear -type f -perm 0644 -print0|xargs -0r grep -l '#!/usr'`
chmod -f 0755 `find %{buildroot}%{_datadir}/flightgear -type f -perm 0644 -print0|xargs -0r grep -l '#!/bin'`

# put documentation and license in the proper location
for f in COPYING AUTHORS NEWS README Thanks; do
  mv "$f" "%{buildroot}%{_defaultdocdir}/%{name}"
done
# Move additional license files to docs See boo#987206
mv %{buildroot}%{_datadir}/flightgear/Fonts/LiberationFonts/COPYING %{buildroot}%{_defaultdocdir}/%{name}/COPYING-LiberationFonts
mv %{buildroot}%{_datadir}/flightgear/AI/Aircraft/A330-MRTT/COPYING %{buildroot}%{_defaultdocdir}/%{name}/COPYING-A330-MRTT

# Zero length files in docs can be deleted
find %{buildroot}%{_defaultdocdir}/%{name} -type f -empty -print -delete

%fdupes -s %{buildroot}/%{_datadir}/flightgear
%fdupes -s %{buildroot}%{_defaultdocdir}/%{name}

%files
%defattr(-,root,root,-)
%{_datadir}/flightgear/

%files -n FlightGear-docs
%defattr(-,root,root,-)
%doc %{_defaultdocdir}/%{name}

%changelog
* Tue Sep 26 2017 Mathias.Homann@opensuse.org
- Update to 2017.3.1
  * New AI Model Embraer ERJ 190 with Paintkit and
    liveries Default, Helvetic Airways and Finnair.
  * Add tips provided by forum members.
  * Updated Ukraine Intl Liveries 737-300, 737-800, 767-300
  * ERJ90 AI model update, new Tail and Nacelles +
    Adjusted Paintkit
  * New Liveries for ERJ90 AI model
  * Updated Liveries AI ERJ90 with Nacelles Texture
  * Added ERJ90 model to existing Traffic File
  * Remapped 747-400 AI Model (Top of fuselage)
  * 747-400 Liveries for new model mapping
  * Remapped 747-400 Freighter (Top Fuselage)
    and updated Liveries
  * Switch to the latest DESG fonts
    and add the new Weather symbols MP2017 protocol support.
  * Remapped 767-300 (Top of Fuselage). Ajusted Liveries.
    Added pitch
  * Earthview 2.1 - parallax mapping for cloud layer,
    lightning at night, Rayleigh scattering in atmosphere.
  * Bugfix and noise seed option for ALS thrust flame shader
  * Bugfix for ALS HUD effect/filtering interaction
  * AirBaltic Dash8 Texture
  * Update the Italian translation
  * Update the French translation
  * Added Spanish translation for startup tips.
  * LOT, Vueling TAP and Wideroe Liveries for
    733 738 319 321 AT7 and Dash 8
  * Austrian Airlines Liveries for AI models Fokker 70 &
    Embraer ERJ195
  * Air Mauritius Liveries for ATR 72 & A319
  * Austrian Airlines Livery for new 777-200
  * TAM Brazil AI 777-300 Livery
  * Updated 733 AI. Fixed AC model(s) & Winglets Mapping.
    New Windhshield Texture.
  * New 777-300 Livery for Swiss Airlines
  * A350-900 Model addd to Qatar Airways traffic file
  * Fix particle wake for USS Truman
  * Bug Fix to missing performance data error for
    CRJ 1000 AI model.
  * New AI Model B737-900ER incl Paintkit and 5 liveries
* Wed Jun 21 2017 bwiedemann@suse.com
- drop unneccesary TeX logs to fix build-compare
* Thu Mar  9 2017 wk@ire.pw.edu.pl
- Update to 2017.1.2
* Mon Jan 23 2017 opensuse@dstoecker.de
- update to version 2016.4.4
* Sat Jan  7 2017 davejplater@gmail.com
- Fixed boo#987206 by moving license files for third parties to
  the default doc dir and fdupe the flightgear data dir and doc dir
  seperately.
- Split off documentation into a sub package
- Added FlightGear-data-rpmlintrc to suppress many warnigs about
  needed hidden files and make rpmlint output more readable.
* Sun Aug 21 2016 mailaender@opensuse.org
- Update to 2016.2.1
* Sun Mar 20 2016 bosim@opensuse.org
- Added SourceURL
* Mon Mar 14 2016 bosim@opensuse.org
- Update to 2016.1.1
* Wed Nov 25 2015 rpm@fthiessen.de
- Update to 3.7.0
* Mon Sep 23 2013 Mathias.Homann@opensuse.org
- update to 2.12.0
* Tue Mar 19 2013 joop.boonen@opensuse.org
- update to 2.10.0
* Thu Aug 23 2012 thorstenb@flightgear.org
- Fix "OpenGL error 'invalid operation'" error and crash with some
  graphics cards (FlightGear fgdata commit #6b76ef1a)
* Fri Aug 17 2012 thorstenb@flightgear.org
- update to 2.8.0
* Fri Feb 17 2012 thorstenb@flightgear.org
- update to 2.6.0
- fixed FlightGear help system
* Tue Sep  6 2011 highwaystar.ru@gmail.com
- data moved /usr/share/FlightGear -> /usr/share/flightgear
* Tue Sep  6 2011 highwaystar.ru@gmail.com
- update to 2.4.0
- added fdupes macro
* Mon Mar  1 2010 prusnak@suse.cz
- updated to 2.0.0
- apply fixes from Fedora package by Fabrice Bellet <fabrice@bellet.info>
* Fri Jan  4 2008 lmichnovic@suse.cz
- patched tarball with upstream patch fixing mp chat
* Thu Jan  3 2008 lmichnovic@suse.cz
- update to version 1.0.0
* Wed Nov 28 2007 lmichnovic@suse.cz
- update to 0.9.11-pre2 version
* Thu Nov 22 2007 lmichnovic@suse.cz
- updated data from CVS
